﻿using System;
using System.Text;

namespace DarwinDecriptor
{
    /// <summary>
    /// The string extensions methods
    /// </summary>
    internal static class StringExtensions
    {
        /// <summary>
        /// Reverse string assume that char is <paramref name="charLength"/> length.
        /// </summary>
        /// <param name="input">
        /// String to reverse
        /// </param>
        /// <param name="charLength">
        /// Length of char to reverse
        /// </param>
        /// <returns>
        /// The reversed string.
        /// </returns>
        /// <exception cref="ArgumentException">
        /// Input string length should be a multiple of <paramref name="charLength"/>
        /// </exception>
        /// <example>
        /// <paramref name="input"/> is ABCDEFGH
        /// <paramref name="charLength"/> is 2
        /// Return: GHEFCDAB
        /// <paramref name="input"/> is ABCDEFGH
        /// <paramref name="charLength"/> is 4
        /// Return: EFGHABCD
        /// </example>
        internal static string ReverseString(this string input, int charLength)
        {
            if (input.Length % charLength != 0)
            {
                throw new ArgumentException("Input string length should be a multiple of " + charLength, "input");
            }

            var result = new StringBuilder(input.Length);
            for (int i = input.Length - charLength; i >= 0; i -= charLength)
            {
                result.Append(input.Substring(i, charLength));
            }

            return result.ToString();
        }
    }
}